## -*- coding: utf-8 -*-
## Copyright (C)2007 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

# Python imports
from StringIO import StringIO

# CMF imports
from Products.CMFCore.utils import getToolByName

# Archetypes imports
from Products.Archetypes import listTypes
from Products.Archetypes.Extensions.utils import installTypes, install_subskin

# Products imports
from Products.FaceBook.config import GLOBALS, PROJECTNAME, CATALOG_NAME, CATALOG_TYPE
from Products.FaceBook.tool import configureFaceCatalog

def installCatalog(self, out):
    """ Install LiveSearch Catalog """

    #Check that the tool has not been added using its id
    tool = getToolByName(self, CATALOG_NAME, None)

    if tool is None:
        addTool = self.manage_addProduct[PROJECTNAME].manage_addTool
        addTool(CATALOG_TYPE)
        print >> out, "added livesearch catalog"

        tool = getToolByName(self, CATALOG_NAME)
        configureFaceCatalog(tool, None)

def updateSearchCatalogTypes(self, out):
    """
    Update Archetypes tool catalog definition
    """

    atool = getToolByName(self, "archetype_tool")

    for item in listTypes(PROJECTNAME):
        ptype = item['portal_type']
        atool.setCatalogsByType('PersonalCard', ('face_catalog',))
        print >> out, "For PersonalCard set face_catalog catalog"

def installProfile(self, out):
    """Install generic setup profile
    """
    stool = getToolByName(self, "portal_setup")
    stool.setImportContext("profile-Products.FaceBook:install")
    stool.runImportStep("workflow")
    print >> out, "generic setup profile imported"
    return out

def install(self):
     """Install content types, skin layer, enable the portal factory
     """
     out = StringIO()

     print >> out, "Installing FaceBook"

     # Install types
     classes = listTypes(PROJECTNAME)
     installTypes(self, out,
                  classes,
                  PROJECTNAME)
     print >> out, "Installed types"

     # Install skin
     install_subskin(self, out, GLOBALS)
     print >> out, "Installed skin"

     # Register types with portal_factory
     factory = getToolByName(self, 'portal_factory')
     types = factory.getFactoryTypes().keys()
     if 'PersonalCard' not in types:
         types.append('PersonalCard')
         factory.manage_setPortalFactoryTypes(listOfTypeIds = types)
     if 'Service' not in types:
         types.append('Service')
         factory.manage_setPortalFactoryTypes(listOfTypeIds = types)

     print >> out, "Added PersonalCard and Service to portal_factory"

     installCatalog(self, out)
     updateSearchCatalogTypes(self, out)

     # Import generic setup profile
     installProfile(self, out)

     return out.getvalue()
