## -*- coding: utf-8 -*-
## Copyright (C)2007 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

from Products.Archetypes.atapi import process_types, listTypes
from Products.CMFCore import utils
from Products.CMFCore.DirectoryView import registerDirectory
from Products.CMFPlone.CatalogTool import registerIndexableAttribute

# Product imports
from config import PROJECTNAME, SKINS_DIR, GLOBALS
from content.personalcard import IPersonalCard

# Import the content types modules
from content import *
# Import the content types permissions
from permissions import ADD_CONTENT_PERMISSIONS
from tool import FaceCatalog

registerDirectory(SKINS_DIR, GLOBALS)

def getName(obj, **kwargs):
    """
        Helper method for the name index.
    """
    if IPersonalCard.providedBy(obj):
        return obj.getName().lower()
    else:
        return obj.getName()

def getSurname(obj, **kwargs):
    """
        Helper method for the surname index.
    """
    if IPersonalCard.providedBy(obj):
        return obj.getSurname().lower()
    else:
        return obj.getSurname()

def initialize(context):
    # Apply catalog helpers
    registerIndexableAttribute('getName', getName)
    registerIndexableAttribute('getSurname', getSurname)

    content_types, constructors, ftis = process_types(
             listTypes(PROJECTNAME),
             PROJECTNAME)

    allTypes = zip(content_types, constructors)
    for atype, constructor in allTypes:
        kind = "%s: %s" % (PROJECTNAME, atype.portal_type)
        utils.ContentInit(kind,
                          content_types      = (atype,),
                          permission         = ADD_CONTENT_PERMISSIONS[atype.portal_type],
                          extra_constructors = (constructor,),
                          fti                = ftis,
                          ).initialize(context)

    # Initialize tools
    tool = utils.ToolInit(
        '%s tool' % PROJECTNAME,
        tools=(FaceCatalog,),
        icon='tool.gif')
    tool.initialize(context)
