## -*- coding: utf-8 -*-
## Copyright (C)2007 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

# Zope imports
from AccessControl import ClassSecurityInfo
from zope.interface import Interface, implements

# Products imports
from Products.FaceBook.config import PROJECTNAME, I18N_DOMAIN
from Products.validation import V_REQUIRED
from Products.ATContentTypes.configuration import zconf

# Archetypes imports
from Products.Archetypes.public import *

PersonalCardSchema = BaseSchema.copy() + Schema((
     StringField(
         'name',
         default='',
         required=True,
         widget=StringWidget(label='Name',
             label_msgid='label_name',
             i18n_domain=I18N_DOMAIN,
             )
     ),
     StringField(
         'surname',
         default='',
         required=True,
         widget=StringWidget(label='Surname',
             label_msgid='label_surname',
             i18n_domain=I18N_DOMAIN,
             )
     ),
     StringField(
         'email',
         required=True,
         validators = ("isEmail",),
         widget=StringWidget(label='Email',
             label_msgid='label_email',
             i18n_domain=I18N_DOMAIN,
             )
     ),
     StringField(
         'phone',
         required=True,
         validators = ("isInternationalPhoneNumber",),
         widget=StringWidget(label='Phone number',
             label_msgid='label_phone_number',
             i18n_domain=I18N_DOMAIN,
             )
     ),
     StringField(
         'function',
          widget=StringWidget(label='Function',
             label_msgid='label_function',
             i18n_domain=I18N_DOMAIN,
             )
     ),
     ImageField(
         'photo',
          swallowResizeExceptions = zconf.swallowImageResizeExceptions.enable,
          pil_quality=zconf.pil_config.quality,
          pil_resize_algo=zconf.pil_config.resize_algo,
          max_size=zconf.ATImage.max_image_dimension,
          sizes={'small': (85,100), 'normal': (300,300)},
          validators=(('isNonEmptyFile', V_REQUIRED),
                      ('checkImageMaxSize', V_REQUIRED)),
          widget=ImageWidget(label = 'Photo',
              label_msgid='label_photo',
              i18n_domain=I18N_DOMAIN,)
     ),
     ))

def finalizeCardSchema(schema):
    schema['title'] = ComputedField(
                        name='title',
                        searchable=1,
                        expression="'%s %s' % (context.getName(), context.getSurname())",
                        mode="r",
                        accessor='Title',
                        widget=StringWidget(
                            label_msgid='label_title',
                            visible={'view': 'invisible', 'edit': 'invisible',},
                            i18n_domain='plone',
                        ),
                    )

    del schema['description']
    return schema.copy()

PersonalCardSchema = finalizeCardSchema(PersonalCardSchema)

class IPersonalCard(Interface):
    pass

class PersonalCard(BaseContent):
    """
    Card used to store personal information about an individual
    """
    implements(IPersonalCard)

    portal_type = meta_type = 'PersonalCard'
    archetype_name = 'personal card'
    typeDescription = 'Card used to store personal information about an individual.'
    typeDescMsgId = 'description_edit_personalcard'

    schema = PersonalCardSchema

    immediate_view = 'personalcard'
    default_view = 'personalcard'
    aliases = ({'(Default)' : default_view,
                'view'      : default_view,
                'base_view' : default_view,
              })

    # Make sure we get title-to-id generation when an object is created
    _at_rename_after_creation = True
    security = ClassSecurityInfo()

    def SearchableName(self):
        """
        Indexed method for text search
        """
        return self.getSurname() + " " + self.getName()

    def sortable_name(self):
        """
        Indexable method for sort
        """
        return self.SearchableName().lower()

    def hasPhoto(self):
        """
        return True if card has a photo
        """
        return self.getPhoto() and True or False

registerType(PersonalCard, PROJECTNAME)
