## -*- coding: utf-8 -*-
## Copyright (C)2007 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

from zope.interface import Interface, implements

from AccessControl import ClassSecurityInfo
from Globals import InitializeClass, DTMLFile

from Products.CMFCore.utils import UniqueObject, getToolByName
from Products.ZCatalog.ZCatalog import ZCatalog
from Products.CMFPlone.CatalogTool import CatalogTool

import config

class IFaceCatalog(Interface):
    """
    Marker interface for FaceCatalog
    """

class args:
    def __init__(self, **kw):
        self.__dict__.update(kw)


class FaceCatalog(CatalogTool):
    """
    Catalog for the Face
    """

    implements(IFaceCatalog)

    title = 'Face Catalog'
    id = config.CATALOG_NAME
    portal_type = meta_type = config.CATALOG_TYPE
    plone_tool = 1

    security = ClassSecurityInfo()

    _properties=(
        {'id':'title', 'type': 'string', 'mode':'w'},)

    def __init__(self):
        ZCatalog.__init__(self, self.getId())
    #    CatalogTool.__init__(self)

    security.declarePublic('enumerateIndexes')
    def enumerateIndexes(self):
        """Returns indexes used by catalog"""
        return (
                ('id', 'FieldIndex', ()),
                ('portal_type', 'FieldIndex', ()),
                ('sortable_name', 'FieldIndex', ()),
                ('SearchableName', 'ZCTextIndex', ()),
                ('path', 'ExtendedPathIndex', ('getPhysicalPath')),
                )

    security.declarePublic('enumerateMetadata')
    def enumerateMetadata(self):
        """Returns metadata used by catalog"""
        return (
                'portal_type',
                'UID',
                'getSurname',
                'getName',
                'hasPhoto',
                'getEmail',
                'getPhone',
                )

    security.declarePublic('enumerateLexicon')
    def enumerateLexicon(self):
        """ return lexicon infos """
        return (
                ('plaintext_lexicon',[
              args(name="Whitespace splitter", group="Word Splitter"),
              args(name="Case Normalizer", group="Case Normalizer"),
              args(name="Remove listed stop words only", group="Stop Words"),
              ]),
                )

def configureFaceCatalog(face_catalog, event=None):
    """
    configure Face Catalog after add
    """

    # add lexicon
    for lexicon_id, elements in  face_catalog.enumerateLexicon():
        face_catalog.manage_addProduct['ZCTextIndex'].manage_addLexicon(
                                      lexicon_id,
                                      elements=elements)
    # add indexes
    for index_name, index_type, index_attr in face_catalog.enumerateIndexes():

        #FIXME: should also check index type?
        if index_name in face_catalog.indexes():
            continue

        if index_type == 'ZCTextIndex':
            extra = args(doc_attr=index_name,
                         lexicon_id=config.CATALOG_LEXICON,
                         index_type='Okapi BM25 Rank')
        elif index_attr:
            extra = args(indexed_attrs=index_attr)
        else:
            extra = {}

        face_catalog.addIndex(index_name, index_type, extra=extra)

    # add metadata
    for metadata_name in face_catalog.enumerateMetadata():
        if metadata_name not in face_catalog.schema():
            face_catalog.addColumn(metadata_name)

    # add face_catalog to types catalogs
    at_tool = getToolByName(face_catalog, "archetype_tool")

    for meta_type in config.CATALOG_TYPES:
        type_catalogs = [catalog.id for catalog in \
                 at_tool.getCatalogsByType(meta_type)]

        if not config.CATALOG_NAME in type_catalogs:
            type_catalogs.append(config.CATALOG_NAME)
            at_tool.setCatalogsByType(meta_type, type_catalogs)

InitializeClass(FaceCatalog)
